@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent qw/autobox/;
 
-our $VERSION = "1.008";
+our $VERSION = "1.009";
 
 =head1 NAME
 
@@ -12,8 +12,37 @@ autobox::Transform - Autobox methods to transform Arrays and Hashes
 
 =head1 SYNOPSIS
 
-    # Comparison of vanilla Perl and autobox version
+=head2 Examples
 
+    use autobox::Core;  # uniq, sort, join, sum, etc.
+    use autobox::Transform;
+
+    $books->map_by("genre");
+    $books->map_by(price_with_tax => [$tax_pct]);
+
+    $books->grep_by("is_sold_out");
+    $books->grep_by(is_in_library => [$library]);
+
+    $books->uniq_by("id");
+
+    $books->group_by("title");
+    $books->group_by_count("genre")
+    $books->group_by_array("genre")
+
+    $authors->map_by("books")->flat;
+
+    my $order_authors = $order->books
+        ->uniq_by("isbn")
+        ->map_by("author")
+        ->map_by("name")->uniq->sort->join(", ");
+
+    my $total_order_amount = $order->books
+        ->grep_by(not_covered_by_vouchers => [ $vouchers ])
+        ->map_by(price_with_tax => [ $tax_pct ])
+        ->sum;
+
+
+=head2 Comparison of vanilla Perl and autobox version
 
     ### map_by - method call: $books are Book objects
     my @genres = map { $_->genre() } @$books;
@@ -102,7 +131,7 @@ autobox::Transform - Autobox methods to transform Arrays and Hashes
 =head1 DESCRIPTION
 
 High level autobox methods you can call on arrays, arrayrefs, hashes
-and hashrefs e.g.
+and hashrefs.
 
 =over 4
 
@@ -175,17 +204,6 @@ succinct and direct code, especially in conjunction with
 autobox::Core.
 
 
-=head2 Examples
-
-    my $total_order_amount = $order->books
-        ->map_by(price_with_tax => [ $tax_pct ])
-        ->sum;
-
-    my $order_authors = $order->books
-        ->uniq_by("isbn")
-        ->map_by("author")
-        ->map_by("name")->uniq->sort->join(", ");
-
 =cut
 
 use true;
